@@ -10,5 +10,5 @@ def main():
     embed(globals(), locals(), vi_mode=False)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
