@@ -19,6 +19,7 @@ from prompt_toolkit.completion import Completer, FuzzyCompleter, ThreadedComplet
 from prompt_toolkit.document import Document
 from prompt_toolkit.enums import DEFAULT_BUFFER, EditingMode
 from prompt_toolkit.filters import Condition
+from prompt_toolkit.formatted_text import AnyFormattedText
 from prompt_toolkit.history import (
     FileHistory,
     History,
@@ -204,6 +205,7 @@ class PythonInput:
         self.extra_key_bindings = extra_key_bindings or KeyBindings()
 
         # Settings.
+        self.title: AnyFormattedText = ""
         self.show_signature: bool = False
         self.show_docstring: bool = False
         self.show_meta_enter_message: bool = True
@@ -322,7 +324,7 @@ class PythonInput:
             extra_toolbars=self._extra_toolbars,
         )
 
-        self.app = self._create_application()
+        self.app = self._create_application(input, output)
 
         if vi_mode:
             self.app.editing_mode = EditingMode.VI
@@ -518,7 +520,7 @@ class PythonInput:
                     ),
                     Option(
                         title="Dictionary completion",
-                        description="Enable experimental dictionary completion.\n"
+                        description="Enable experimental dictionary/list completion.\n"
                         'WARNING: this does "eval" on fragments of\n'
                         "         your Python input and is\n"
                         "         potentially unsafe.",
@@ -726,7 +728,9 @@ class PythonInput:
             ),
         ]
 
-    def _create_application(self) -> Application:
+    def _create_application(
+        self, input: Optional[Input], output: Optional[Output]
+    ) -> Application:
         """
         Create an `Application` instance.
         """
@@ -756,6 +760,8 @@ class PythonInput:
             style_transformation=self.style_transformation,
             include_default_pygments_style=False,
             reverse_vi_search_direction=True,
+            input=input,
+            output=output,
         )
 
     def _create_buffer(self) -> Buffer:
